merge_operations

Function merge_operations 

pub async fn merge_operations(
    ui: Option<&Ui>,
    repo_loader: &RepoLoader,
    operations: Vec<Operation>,
    workspace_name: Option<&WorkspaceName>,
    transaction_description: Option<&str>,
    command_args: &[String],
) -> Result<Operation, CommandError>
If operations is empty returns the root operation, if it contains a single entry returns that entry, otherwise merges the operations into a single operation. If ui is set, reports the number of rebased descendants.