print_large_file_hint

Function print_large_file_hint 

pub fn print_large_file_hint(
    ui: &Ui,
    max_size: u64,
    large_files: Option<&[String]>,
) -> Result<()>
Prints a hint about how to handle large files that were refused during snapshot.

If large_files is provided, the hint will include file-track-specific options like --include-ignored. Otherwise, it shows a simpler hint suitable for general snapshot operations.