pub struct WorkspaceCommandEnvironment { /* private fields */ }Expand description
Metadata and configuration loaded for a specific workspace.
Implementations
Sourceimpl WorkspaceCommandEnvironment
impl WorkspaceCommandEnvironment
pub fn workspace_name(&self) -> &WorkspaceName
Sourcepub fn new_id_prefix_context(&self) -> IdPrefixContext
pub fn new_id_prefix_context(&self) -> IdPrefixContext
Creates fresh new context which manages cache of short commit/change ID prefixes. New context should be created per repo view (or operation.)
Sourcepub fn immutable_expression(&self) -> Arc<UserRevsetExpression>
pub fn immutable_expression(&self) -> Arc<UserRevsetExpression>
User-configured expression defining the immutable set.
Sourcepub fn immutable_heads_expression(&self) -> &Arc<UserRevsetExpression>
pub fn immutable_heads_expression(&self) -> &Arc<UserRevsetExpression>
User-configured expression defining the heads of the immutable set.
Sourcepub fn conflict_marker_style(&self) -> ConflictMarkerStyle
pub fn conflict_marker_style(&self) -> ConflictMarkerStyle
User-configured conflict marker style for materializing conflicts
pub fn template_aliases_map(&self) -> &TemplateAliasesMap
Sourcepub fn parse_template<'a, C, L>(
&self,
ui: &Ui,
language: &L,
template_text: &str,
) -> Result<TemplateRenderer<'a, C>, CommandError>
pub fn parse_template<'a, C, L>( &self, ui: &Ui, language: &L, template_text: &str, ) -> Result<TemplateRenderer<'a, C>, CommandError>
Parses template of the given language into evaluation tree.
Sourcepub fn commit_template_language<'a>(
&'a self,
repo: &'a dyn Repo,
id_prefix_context: &'a IdPrefixContext,
) -> CommitTemplateLanguage<'a>
pub fn commit_template_language<'a>( &'a self, repo: &'a dyn Repo, id_prefix_context: &'a IdPrefixContext, ) -> CommitTemplateLanguage<'a>
Creates commit template language environment for this workspace and the
given repo.
pub fn operation_template_extensions( &self, ) -> &[Arc<dyn OperationTemplateLanguageExtension>]