add_trailers_with_template

Function add_trailers_with_template 

pub fn add_trailers_with_template(
    template: &TemplateRenderer<'_, Commit>,
    commit: &Commit,
) -> Result<String, CommandError>
Add the trailers from the given template in the last paragraph of the description

It just lets the description untouched if the trailers are already there.