pub enum RevsetEvaluationSizeError {
Empty,
Multiple(Vec<Commit>, bool),
Other(UserRevsetEvaluationError),
}Expand description
Error when evaluating a revset into a single commit.
Variants
Empty
The revset evaluated to no commits.
Multiple(Vec<Commit>, bool)
The revset evaluated to multiple commits. The vector only contains a few commits (enough for an error message), and the bool indicates whether there were more; do not expect this to be the entire evaluated revset.
Other(UserRevsetEvaluationError)
An error occurred during revset evaluation; size unknown.
Implementations
Sourceimpl RevsetEvaluationSizeError
impl RevsetEvaluationSizeError
pub fn to_command_error( self, revision_str: &str, commit_summary_template: &TemplateRenderer<'_, Commit>, ) -> CommandError