CoreTemplatePropertyVar

Trait CoreTemplatePropertyVar 

pub trait CoreTemplatePropertyVar<'a>{
Show 13 methods // Required methods fn wrap_template(template: Box<dyn Template + 'a>) -> Self; fn wrap_any(property: BoxedAnyProperty<'a>) -> Self; fn wrap_any_list(property: BoxedAnyProperty<'a>) -> Self; fn type_name(&self) -> &'static str; fn try_into_byte_string( self, ) -> Result<BoxedTemplateProperty<'a, BString>, Self>; fn try_into_string(self) -> Result<BoxedTemplateProperty<'a, String>, Self>; fn try_into_boolean(self) -> Result<BoxedTemplateProperty<'a, bool>, Self>; fn try_into_integer(self) -> Result<BoxedTemplateProperty<'a, i64>, Self>; fn try_into_timestamp( self, ) -> Result<BoxedTemplateProperty<'a, Timestamp>, Self>; fn try_into_serialize(self) -> Option<BoxedSerializeProperty<'a>>; fn try_into_template(self) -> Option<Box<dyn Template + 'a>>; fn try_into_eq(self, other: Self) -> Option<BoxedTemplateProperty<'a, bool>>; fn try_into_cmp( self, other: Self, ) -> Option<BoxedTemplateProperty<'a, Ordering>>;
}
Wrapper for the core template property types.

Required Methods

fn wrap_template(template: Box<dyn Template + 'a>) -> Self

fn wrap_any(property: BoxedAnyProperty<'a>) -> Self

fn wrap_any_list(property: BoxedAnyProperty<'a>) -> Self

fn type_name(&self) -> &'static str

Type name of the property output.

fn try_into_byte_string( self, ) -> Result<BoxedTemplateProperty<'a, BString>, Self>

Extracts property of ByteString type or newtype.

fn try_into_string(self) -> Result<BoxedTemplateProperty<'a, String>, Self>

Extracts property of String type or newtype.

fn try_into_boolean(self) -> Result<BoxedTemplateProperty<'a, bool>, Self>

fn try_into_integer(self) -> Result<BoxedTemplateProperty<'a, i64>, Self>

fn try_into_timestamp( self, ) -> Result<BoxedTemplateProperty<'a, Timestamp>, Self>

fn try_into_serialize(self) -> Option<BoxedSerializeProperty<'a>>

fn try_into_template(self) -> Option<Box<dyn Template + 'a>>

fn try_into_eq(self, other: Self) -> Option<BoxedTemplateProperty<'a, bool>>

Transforms into a property that will evaluate to self == other.

fn try_into_cmp( self, other: Self, ) -> Option<BoxedTemplateProperty<'a, Ordering>>

Transforms into a property that will evaluate to an Ordering.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors