pub trait CoreTemplatePropertyVar<'a>where
Self: WrapTemplateProperty<'a, String> + WrapTemplateProperty<'a, Vec<String>> + WrapTemplateProperty<'a, bool> + WrapTemplateProperty<'a, i64> + WrapTemplateProperty<'a, Option<i64>> + WrapTemplateProperty<'a, ConfigValue> + WrapTemplateProperty<'a, Option<ConfigValue>> + WrapTemplateProperty<'a, Signature> + WrapTemplateProperty<'a, Email> + WrapTemplateProperty<'a, SizeHint> + WrapTemplateProperty<'a, Timestamp> + WrapTemplateProperty<'a, TimestampRange>,{
// Required methods
fn wrap_template(template: Box<dyn Template + 'a>) -> Self;
fn wrap_any(property: BoxedAnyProperty<'a>) -> Self;
fn wrap_any_list(property: BoxedAnyProperty<'a>) -> Self;
fn type_name(&self) -> &'static str;
fn try_into_boolean(self) -> Option<BoxedTemplateProperty<'a, bool>>;
fn try_into_integer(self) -> Option<BoxedTemplateProperty<'a, i64>>;
fn try_into_timestamp(self) -> Option<BoxedTemplateProperty<'a, Timestamp>>;
fn try_into_stringify(self) -> Option<BoxedTemplateProperty<'a, String>>;
fn try_into_serialize(self) -> Option<BoxedSerializeProperty<'a>>;
fn try_into_template(self) -> Option<Box<dyn Template + 'a>>;
fn try_into_eq(self, other: Self) -> Option<BoxedTemplateProperty<'a, bool>>;
fn try_into_cmp(
self,
other: Self,
) -> Option<BoxedTemplateProperty<'a, Ordering>>;
}Expand description
Wrapper for the core template property types.
Required Methods
fn wrap_template(template: Box<dyn Template + 'a>) -> Self
fn wrap_any(property: BoxedAnyProperty<'a>) -> Self
fn wrap_any_list(property: BoxedAnyProperty<'a>) -> Self
fn try_into_boolean(self) -> Option<BoxedTemplateProperty<'a, bool>>
fn try_into_integer(self) -> Option<BoxedTemplateProperty<'a, i64>>
fn try_into_timestamp(self) -> Option<BoxedTemplateProperty<'a, Timestamp>>
Sourcefn try_into_stringify(self) -> Option<BoxedTemplateProperty<'a, String>>
fn try_into_stringify(self) -> Option<BoxedTemplateProperty<'a, String>>
Transforms into a string property by formatting the value if needed.
fn try_into_serialize(self) -> Option<BoxedSerializeProperty<'a>>
fn try_into_template(self) -> Option<Box<dyn Template + 'a>>
Sourcefn try_into_eq(self, other: Self) -> Option<BoxedTemplateProperty<'a, bool>>
fn try_into_eq(self, other: Self) -> Option<BoxedTemplateProperty<'a, bool>>
Transforms into a property that will evaluate to self == other.
Sourcefn try_into_cmp(
self,
other: Self,
) -> Option<BoxedTemplateProperty<'a, Ordering>>
fn try_into_cmp( self, other: Self, ) -> Option<BoxedTemplateProperty<'a, Ordering>>
Transforms into a property that will evaluate to an Ordering.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.